==> zen-cart-v1.2.0-l10n-jp-5.zip: zen-cart-v1.2.0-l10n-jp-5/includes/languages/japanese/product_free_shipping_info.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2004 The zen-cart developers                           |
// |                                                                      |   
// | http://www.zen-cart.com/index.php                                    |   
// |                                                                      |   
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
// $Id: product_free_shipping_info.php,v 1.5 2004/11/20 05:54:47 shidairiki Exp $
//

define('TEXT_PRODUCT_NOT_FOUND', 'ʤĤޤǤ');
define('TEXT_CURRENT_REVIEWS', 'ߤΥӥ塼:');
define('TEXT_MORE_INFORMATION', 'ܤϤξʤ<a href="%s" target="_blank">Webڡ</a>');
define('TEXT_DATE_ADDED', 'ξʤ %s Ͽޤ');
define('TEXT_DATE_AVAILABLE', '<font color="#ff0000">ξʤ %s ͽǤ</font>');
define('TEXT_ALSO_PURCHASED_PRODUCTS', 'ξʤ򤪵ϤΤ褦ʾʤ⤪ˤʤäƤޤ');
define('TEXT_PRODUCT_OPTIONS', '<strong>Ӥ:</strong>');
define('TEXT_PRODUCT_MANUFACTURER', '᡼: ');
define('TEXT_PRODUCT_WEIGHT', 'Ѳٽ: ');
define('TEXT_PRODUCT_WEIGHT_UNIT', ' kg');
define('TEXT_PRODUCT_QUANTITY', ' ߸');
define('TEXT_PRODUCT_MODEL', 'ǥ: ');



// previous next product
define('PREV_NEXT_PRODUCT', ' ');
define('PREV_NEXT_FROM', ' from ');
define('IMAGE_BUTTON_PREVIOUS','Υƥ');
define('IMAGE_BUTTON_NEXT','Υƥ');
define('IMAGE_BUTTON_RETURN_TO_PRODUCT_LIST','ʥꥹȤ');

// missing products
//define('TABLE_HEADING_NEW_PRODUCTS', '徦 %s');
//define('TABLE_HEADING_UPCOMING_PRODUCTS', 'ͽ꾦');
//define('TABLE_HEADING_DATE_EXPECTED', '');

define('TEXT_ATTRIBUTES_PRICE_WAS',' [: ');
define('TEXT_ATTRIBUTE_IS_FREE',' ʤ: ̵]');
define('TEXT_ONETIME_CHARGE_SYMBOL', ' *');
define('TEXT_ONETIME_CHARGE_DESCRIPTION', ' 󥿥⤬ŬѤޤ');
define('TEXT_ATTRIBUTES_QTY_PRICE_HELP_LINK','̳ޤ');
define('ATTRIBUTES_QTY_PRICE_SYMBOL', zen_image(DIR_WS_TEMPLATE_ICONS . 'icon_status_green.gif', TEXT_ATTRIBUTES_QTY_PRICE_HELP_LINK, 10, 10) . '&nbsp;');

?>

==> zen-cart-v1.3.0.2-l10n-jp-5.zip: zen-cart-v1.3.0.2-l10n-jp-5/includes/languages/japanese/product_free_shipping_info.php <==
<?php
/**
 * @package languageDefines
 * @copyright Copyright 2003-2006 Zen Cart Development Team
 * @copyright Portions Copyright 2003 osCommerce
 * @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
 * @version $Id: product_free_shipping_info.php 3027 2006-02-13 17:15:51Z drbyte $
 */

define('TEXT_PRODUCT_NOT_FOUND', '뾦ʤϸĤޤǤ');
define('TEXT_CURRENT_REVIEWS', 'ߤΥӥ塼:');
define('TEXT_MORE_INFORMATION', 'ܤϤξʤ<a href="%s" target="_blank">Webڡ</a>');
define('TEXT_DATE_ADDED', 'ξʤ %s Ͽޤ');
define('TEXT_DATE_AVAILABLE', 'ξʤ %s ͽǤ');
define('TEXT_ALSO_PURCHASED_PRODUCTS', 'ξʤ򤪵ϤΤ褦ʾʤ⤪Ǥ');
define('TEXT_PRODUCT_OPTIONS', '򤷤Ƥ:');
define('TEXT_PRODUCT_MANUFACTURER', '᡼: ');
define('TEXT_PRODUCT_WEIGHT', ': ');
define('TEXT_PRODUCT_QUANTITY', ' ߸');
define('TEXT_PRODUCT_MODEL', 'ǥ: ');



// previous next product
define('PREV_NEXT_PRODUCT', ' ');
define('PREV_NEXT_FROM', ' from ');
define('IMAGE_BUTTON_PREVIOUS','Υƥ');
define('IMAGE_BUTTON_NEXT','Υƥ');
define('IMAGE_BUTTON_RETURN_TO_PRODUCT_LIST','ʥꥹȤ');

// missing products
//define('TABLE_HEADING_NEW_PRODUCTS', '徦 %s');
//define('TABLE_HEADING_UPCOMING_PRODUCTS', 'ͽ꾦');
//define('TABLE_HEADING_DATE_EXPECTED', '');

define('TEXT_ATTRIBUTES_PRICE_WAS',' [: ');
define('TEXT_ATTRIBUTE_IS_FREE',' ʤ: ̵]');
define('TEXT_ONETIME_CHARGE_SYMBOL', ' *');
define('TEXT_ONETIME_CHARGE_DESCRIPTION', ' ⤬ޤ');
define('TEXT_ATTRIBUTES_QTY_PRICE_HELP_LINK','̳ޤ');
define('ATTRIBUTES_QTY_PRICE_SYMBOL', zen_image(DIR_WS_TEMPLATE_ICONS . 'icon_status_green.gif', TEXT_ATTRIBUTES_QTY_PRICE_HELP_LINK, 10, 10) . '&nbsp;');

?>
